@@ -1,7 +1,7 @@
-__version__ = "0.7.9"
-__version_info__ = ['0', '7', '9']
+__version__ = "0.8"
+__version_info__ = ['0', '8']
 __version_vcs_info__ = {'branch': 'master',
- 'revid': '3a1736f',
- 'revno': 873,
+ 'revid': '94d52d1',
+ 'revno': 1267,
  'toplevel': '/home/saxtouri/src/kamaki/kamaki'}
 __version_user_info__ = "saxtouri@terminus"
